Documentation
¶
Index ¶
- func GoogleBinaryAuthorizationAttestor_IsConstruct(x interface{}) *bool
- func GoogleBinaryAuthorizationAttestor_TfResourceType() *string
- func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference_Override(g GoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference, ...)
- func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList_Override(g GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList, ...)
- func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference_Override(...)
- func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference_Override(...)
- func NewGoogleBinaryAuthorizationAttestorTimeoutsOutputReference_Override(g GoogleBinaryAuthorizationAttestorTimeoutsOutputReference, ...)
- func NewGoogleBinaryAuthorizationAttestor_Override(g GoogleBinaryAuthorizationAttestor, scope constructs.Construct, id *string, ...)
- type GoogleBinaryAuthorizationAttestor
- type GoogleBinaryAuthorizationAttestorAttestationAuthorityNote
- type GoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference
- type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeys
- type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList
- type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference
- type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey
- type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference
- type GoogleBinaryAuthorizationAttestorConfig
- type GoogleBinaryAuthorizationAttestorTimeouts
- type GoogleBinaryAuthorizationAttestorTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleBinaryAuthorizationAttestor_IsConstruct ¶
func GoogleBinaryAuthorizationAttestor_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleBinaryAuthorizationAttestor_TfResourceType ¶
func GoogleBinaryAuthorizationAttestor_TfResourceType() *string
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference_Override ¶
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference_Override(g GoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList_Override ¶
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList_Override(g GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference_Override ¶
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference_Override(g GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference_Override ¶
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference_Override(g GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBinaryAuthorizationAttestorTimeoutsOutputReference_Override ¶
func NewGoogleBinaryAuthorizationAttestorTimeoutsOutputReference_Override(g GoogleBinaryAuthorizationAttestorTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBinaryAuthorizationAttestor_Override ¶
func NewGoogleBinaryAuthorizationAttestor_Override(g GoogleBinaryAuthorizationAttestor, scope constructs.Construct, id *string, config *GoogleBinaryAuthorizationAttestorConfig)
Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor google_binary_authorization_attestor} Resource.
Types ¶
type GoogleBinaryAuthorizationAttestor ¶
type GoogleBinaryAuthorizationAttestor interface {
cdktf.TerraformResource
AttestationAuthorityNote() GoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference
AttestationAuthorityNoteInput() *GoogleBinaryAuthorizationAttestorAttestationAuthorityNote
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleBinaryAuthorizationAttestorTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAttestationAuthorityNote(value *GoogleBinaryAuthorizationAttestorAttestationAuthorityNote)
PutTimeouts(value *GoogleBinaryAuthorizationAttestorTimeouts)
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor google_binary_authorization_attestor}.
func NewGoogleBinaryAuthorizationAttestor ¶
func NewGoogleBinaryAuthorizationAttestor(scope constructs.Construct, id *string, config *GoogleBinaryAuthorizationAttestorConfig) GoogleBinaryAuthorizationAttestor
Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor google_binary_authorization_attestor} Resource.
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNote ¶
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNote struct {
// The resource name of a ATTESTATION_AUTHORITY Note, created by the user.
//
// If the Note is in a different project from the Attestor, it
// should be specified in the format 'projects/*\/notes/*' (or the legacy
// 'providers/*\/notes/*'). This field may not be updated.
// An attestation by this attestor is stored as a Container Analysis
// ATTESTATION_AUTHORITY Occurrence that names a container image
// and that links to this Note.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#note_reference GoogleBinaryAuthorizationAttestor#note_reference}
NoteReference *string `field:"required" json:"noteReference" yaml:"noteReference"`
// public_keys block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#public_keys GoogleBinaryAuthorizationAttestor#public_keys}
PublicKeys interface{} `field:"optional" json:"publicKeys" yaml:"publicKeys"`
}
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference ¶
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DelegationServiceAccountEmail() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleBinaryAuthorizationAttestorAttestationAuthorityNote
SetInternalValue(val *GoogleBinaryAuthorizationAttestorAttestationAuthorityNote)
NoteReference() *string
SetNoteReference(val *string)
NoteReferenceInput() *string
PublicKeys() GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList
PublicKeysInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutPublicKeys(value interface{})
ResetPublicKeys()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference ¶
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeys ¶
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeys struct {
// ASCII-armored representation of a PGP public key, as the entire output by the command 'gpg --export --armor foo@example.com' (either LF or CRLF line endings). When using this field, id should be left blank. The BinAuthz API handlers will calculate the ID and fill it in automatically. BinAuthz computes this ID as the OpenPGP RFC4880 V4 fingerprint, represented as upper-case hex. If id is provided by the caller, it will be overwritten by the API-calculated ID.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#ascii_armored_pgp_public_key GoogleBinaryAuthorizationAttestor#ascii_armored_pgp_public_key}
AsciiArmoredPgpPublicKey *string `field:"optional" json:"asciiArmoredPgpPublicKey" yaml:"asciiArmoredPgpPublicKey"`
// A descriptive comment. This field may be updated.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#comment GoogleBinaryAuthorizationAttestor#comment}
Comment *string `field:"optional" json:"comment" yaml:"comment"`
// The ID of this public key.
//
// Signatures verified by BinAuthz
// must include the ID of the public key that can be used to
// verify them, and that ID must match the contents of this
// field exactly. Additional restrictions on this field can
// be imposed based on which public key type is encapsulated.
// See the documentation on publicKey cases below for details.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#id GoogleBinaryAuthorizationAttestor#id}
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// pkix_public_key block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#pkix_public_key GoogleBinaryAuthorizationAttestor#pkix_public_key}
PkixPublicKey *GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey `field:"optional" json:"pkixPublicKey" yaml:"pkixPublicKey"`
}
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList ¶
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList ¶
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference ¶
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference interface {
cdktf.ComplexObject
AsciiArmoredPgpPublicKey() *string
SetAsciiArmoredPgpPublicKey(val *string)
AsciiArmoredPgpPublicKeyInput() *string
Comment() *string
SetComment(val *string)
CommentInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
SetId(val *string)
IdInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
PkixPublicKey() GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference
PkixPublicKeyInput() *GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutPkixPublicKey(value *GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey)
ResetAsciiArmoredPgpPublicKey()
ResetComment()
ResetId()
ResetPkixPublicKey()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference ¶
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey ¶
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey struct {
// A PEM-encoded public key, as described in 'https://tools.ietf.org/html/rfc7468#section-13'.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#public_key_pem GoogleBinaryAuthorizationAttestor#public_key_pem}
PublicKeyPem *string `field:"optional" json:"publicKeyPem" yaml:"publicKeyPem"`
// The signature algorithm used to verify a message against a signature using this key.
//
// These signature algorithm must
// match the structure and any object identifiers encoded in
// publicKeyPem (i.e. this algorithm must match that of the
// public key).
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#signature_algorithm GoogleBinaryAuthorizationAttestor#signature_algorithm}
SignatureAlgorithm *string `field:"optional" json:"signatureAlgorithm" yaml:"signatureAlgorithm"`
}
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference ¶
type GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey
SetInternalValue(val *GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey)
PublicKeyPem() *string
SetPublicKeyPem(val *string)
PublicKeyPemInput() *string
SignatureAlgorithm() *string
SetSignatureAlgorithm(val *string)
SignatureAlgorithmInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPublicKeyPem()
ResetSignatureAlgorithm()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference ¶
func NewGoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference
type GoogleBinaryAuthorizationAttestorConfig ¶
type GoogleBinaryAuthorizationAttestorConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// attestation_authority_note block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#attestation_authority_note GoogleBinaryAuthorizationAttestor#attestation_authority_note}
AttestationAuthorityNote *GoogleBinaryAuthorizationAttestorAttestationAuthorityNote `field:"required" json:"attestationAuthorityNote" yaml:"attestationAuthorityNote"`
// The resource name.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#name GoogleBinaryAuthorizationAttestor#name}
Name *string `field:"required" json:"name" yaml:"name"`
// A descriptive comment. This field may be updated. The field may be displayed in chooser dialogs.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#description GoogleBinaryAuthorizationAttestor#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#id GoogleBinaryAuthorizationAttestor#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#project GoogleBinaryAuthorizationAttestor#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#timeouts GoogleBinaryAuthorizationAttestor#timeouts}
Timeouts *GoogleBinaryAuthorizationAttestorTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleBinaryAuthorizationAttestorTimeouts ¶
type GoogleBinaryAuthorizationAttestorTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#create GoogleBinaryAuthorizationAttestor#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#delete GoogleBinaryAuthorizationAttestor#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_binary_authorization_attestor#update GoogleBinaryAuthorizationAttestor#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleBinaryAuthorizationAttestorTimeoutsOutputReference ¶
type GoogleBinaryAuthorizationAttestorTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBinaryAuthorizationAttestorTimeoutsOutputReference ¶
func NewGoogleBinaryAuthorizationAttestorTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBinaryAuthorizationAttestorTimeoutsOutputReference
Source Files
¶
- googlebinaryauthorizationattestor.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestor.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNote.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNoteOutputReference__runtime_type_checks.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeys.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysList__runtime_type_checks.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysOutputReference__runtime_type_checks.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKey.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorAttestationAuthorityNotePublicKeysPkixPublicKeyOutputReference__runtime_type_checks.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorConfig.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorTimeouts.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorTimeoutsOutputReference.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestorTimeoutsOutputReference__runtime_type_checks.go
- googlebinaryauthorizationattestor_GoogleBinaryAuthorizationAttestor__runtime_type_checks.go